@@ -33,13 +33,26 @@ class GraphStepPerformer(StepPerformer):
             sheet_index: int
             x_axis_column_ids: ColumnID[],
             y_axis_column_ids: ColumnID[],
-            color: (optional) {type: 'variable', columnID: columnID} | {type: 'constant', color_mapping: Record<ColumnID, string>}
-
-            Note: Color is not in the styles object because it can either be a variable or a discrete color.
-            Color as a variable does not belong in the style object. However, I want to keep the variable
-            and constant color together so we can ensure through the type system that only one can be set at a time.
+            color: columnID: columnID
+        },
+        graph_styling: {
+            title: {
+                title: string | None
+                visible: boolean
+            },
+            xaxis: {
+                title: string | None,
+                visible: boolean,
+                rangeslider: {
+                    visible: boolean
+                }
+            },
+            yaxis: {
+                title: string | None,
+                visible: boolean
+            },
+            showlegend: boolean
         },
-        graph_styling: {},
         graph_rendering: {
             height: int representing the div width
             width: int representing the div width
@@ -49,7 +62,7 @@ class GraphStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 1
+        return 3
 
     @classmethod
     def step_type(cls) -> str:
@@ -59,10 +72,6 @@ class GraphStepPerformer(StepPerformer):
     def step_display_name(cls) -> str:
         return "Created a graph"
 
-    @classmethod
-    def step_event_type(cls) -> str:
-        return "graph_edit"
-
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         return params
@@ -83,7 +92,7 @@ class GraphStepPerformer(StepPerformer):
         """
 
         # We make a new state to modify it
-        post_state = deepcopy(prev_state)
+        post_state = prev_state.copy()
 
         # Extract variables from graph parameters
         graph_type = graph_creation["graph_type"]
@@ -100,6 +109,9 @@ class GraphStepPerformer(StepPerformer):
         y_axis_column_ids = graph_creation["y_axis_column_ids"] if graph_creation["y_axis_column_ids"] is not None else []
         y_axis_column_headers = prev_state.column_ids.get_column_headers_by_ids(sheet_index, y_axis_column_ids)
 
+        # Validate optional parameters 
+        color_column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, graph_creation["color"]) if 'color' in graph_creation.keys() else None
+
         # Create a copy of the dataframe, just for safety.
         df: pd.DataFrame = prev_state.dfs[sheet_index].copy()
         df_name: str = prev_state.df_names[sheet_index]
@@ -129,6 +141,8 @@ class GraphStepPerformer(StepPerformer):
                 safety_filter_turned_on_by_user,
                 x_axis_column_headers,
                 y_axis_column_headers,
+                color_column_header,
+                graph_styling
             )
             pandas_processing_time = perf_counter() - pandas_start_time
 
@@ -150,6 +164,8 @@ class GraphStepPerformer(StepPerformer):
                 safety_filter_turned_on_by_user,
                 x_axis_column_headers,
                 y_axis_column_headers,
+                color_column_header,
+                graph_styling,
                 df_name,
             )
 
